@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+from paste.deploy.converters import asbool
 from paste.httpexceptions import HTTPFound, HTTPUnauthorized
 from paste.httpheaders import SET_COOKIE
 from paste.request import get_cookies, construct_url, parse_formvars, resolve_relative_url
@@ -188,6 +189,7 @@ def make_redirecting_plugin(login_form_path=None,
                             login_handler_path=None,
                             logout_handler_path=None,
                             rememberer_name=None,
+                            default_redirect_path='/',
                             login_redirect_method='cookie',
                             logout_redirect_method='cookie',
                             force_https=False,
@@ -226,6 +228,7 @@ def make_redirecting_plugin(login_form_path=None,
     if rememberer_name is None:
         raise ValueError(
             'must include rememberer (name of another IIdentifier plugin)')
+    force_https = asbool(force_https)
     if not isinstance(force_https, bool):
         raise ValueError(
             'force_https must be a boolean!')
@@ -234,7 +237,8 @@ def make_redirecting_plugin(login_form_path=None,
                                    login_handler_path,
                                    logout_handler_path,
                                    rememberer_name,
-                                   login_redirect_method,
+                                   default_redirect_path,
                                    logout_redirect_method,
+                                   login_redirect_method,
                                    force_https,
                                    **kw)
